netapp_ontap.models.auto_update_info_eula API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.auto_update_info_eula`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class AutoUpdateInfoEulaSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the AutoUpdateInfoEula object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `accepted: bool GET`

    Flag indicating the End User License Agreement (EULA) acceptance. When the feature is enabled, it is assumed that the EULA is accepted.

    Example: true

  `accepted_ip_address: str GET`

    IP Address from where the EULA was accepted.

    Example: 192.168.1.125

  `accepted_timestamp: ImpreciseDateTime GET`

    Date and time when the EULA was accepted.

    Example: 2020-12-01T13:12:23.000+0000

  `user_id_accepted: str GET`

    User ID that provided the EULA acceptance.

    Example: admin